"""
Local methods that correspond to this API documentation page

http://api.votesmart.org/docs/Local.html
"""

from .base import APIMethodBase
from .containers import VotesmartApiObject

class Locality(VotesmartApiObject):
    def __str__(self):
        return self.name

class Official(VotesmartApiObject):
    def __str__(self):
        return ' '.join((self.title, self.firstName, self.lastName))

class Local(APIMethodBase):

    def getCounties(self, stateId):
        params = {'stateId': stateId}
        result = self.api.api_call('Local.getCounties', params)
        return self.result_to_obj(Locality, result['counties']['county'])

    def getCities(self, stateId):
        params = {'stateId': stateId}
        result = self.api.api_call('Local.getCities', params)
        return self.result_to_obj(Locality, result['cities']['city'])

    def getOfficials(self, localId):
        params = {'localId': localId}
        result = self.api.api_call('Local.getOfficials', params)
        return self.result_to_obj(Official, result['candidateList']['candidate'])



"""
Officials methods that correspond to this API documentation page

http://api.votesmart.org/docs/Officials.html
"""

from .base import APIMethodBase
from .containers import VotesmartApiObject

class Official(VotesmartApiObject):
    def __str__(self):
        return ' '.join((self.title, self.firstName, self.lastName))

class OfficeType(VotesmartApiObject):
    def __str__(self):
        return ': '.join((self.officeTypeId, self.name))


class Officials(APIMethodBase):

    def getTypes(self):
        result = self.api.api_call('Office.getTypes', {})
        return self.result_to_obj(OfficeType, result['officeTypes']['type'])

    def getStatewide(self, stateId=None):
        params = {'stateId': stateId}
        result = self.api.api_call('Officials.getStatewide', params)
        return self.result_to_obj(Official, result['candidateList']['candidate'])

    def getByOfficeState(self, officeId, stateId=None):
        params = {'officeId':officeId, 'stateId': stateId}
        result = self.api.api_call('Officials.getByOfficeState', params)
        return self.result_to_obj(Official, result['candidateList']['candidate'])

    def getByLastname(self, lastName):
        params = {'lastName':lastName}
        result = self.api.api_call('Officials.getByLastname', params)
        return self.result_to_obj(Official, result['candidateList']['candidate'])

    def getByLevenstein(self, lastName):
        params = {'lastName':lastName}
        result = self.api.api_call('Officials.getByLevenstein', params)
        return self.result_to_obj(Official, result['candidateList']['candidate'])

    def getByDistrict(self, districtId):
        params = {'districtId':districtId}
        result = self.api.api_call('Officials.getByDistrict', params)
        return self.result_to_obj(Official, result['candidateList']['candidate'])

    def getByZip(self, zip5, zip4=None):
        params = {'zip4': zip4, 'zip5': zip5}
        result = self.api.api_call('Officials.getByZip', params)
        return self.result_to_obj(Official, result['candidateList']['candidate'])



"""
Npat methods that correspond to this API documentation page

Political Courage Test

Returns a candidates most recently filled out Political Courage Test.

http://api.votesmart.org/docs/Npat.html
"""

from .base import APIMethodBase

class Npat(APIMethodBase):

    def getNpat(self, candidateId):
        params = {'candidateId':candidateId}
        result = self.api.api_call('Npat.getNpat', params)
        return result['npat']



"""
Measure methods that correspond to this API documentation page

http://api.votesmart.org/docs/Measure.html
"""

from .base import APIMethodBase
from .containers import VotesmartApiObject

class MeasureList(VotesmartApiObject):
    def __str__(self):
        return self.title

class MeasureDetail(VotesmartApiObject):
    def __str__(self):
        return self.title


class Measure(APIMethodBase):

    def getMeasuresByYearState(self, year, stateId):
        params = {'year':year, 'stateId':stateId}
        result = self.api.api_call('Measure.getMeasuresByYearState', params)
        return self.result_to_obj(MeasureList, result['measures']['measure'])

    def getMeasure(self, measureId):
        params = {'measureId':measureId}
        result = self.api.api_call('Measure.getMeasure', params)
        return MeasureDetail(result['measure'])



"""
Leadership methods that correspond to this API documentation page

http://api.votesmart.org/docs/Leadership.html
"""

from .base import APIMethodBase
from .containers import VotesmartApiObject

class LeadershipPosition(VotesmartApiObject):
    def __str__(self):
        return self.name

class Leadership(APIMethodBase):

    def getPositions(self, stateId=None, officeId=None):
        params = {'stateId':stateId, 'officeId':officeId}
        result = self.api.api_call('Leadership.getPositions', params)
        return self.result_to_obj(LeadershipPosition, result['leadership']['position'])

    def getOfficials(self, leadershipId, stateId=None):
       params = {'leadershipId':leadershipId, 'stateId':stateId}
       result = self.api.api_call('Leadership.getOfficials', params)
       return result['leaders']['leader']
